package com.aitrainer.api.controller

import com.aitrainer.api.model.ExerciseType
import com.aitrainer.api.repository.ExerciseTypeRepository
import org.slf4j.LoggerFactory

import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

@RestController
@RequestMapping("/api")
class ExerciseTypeController ( private val exerciseTypeRepository: ExerciseTypeRepository ) {
    private val logger = LoggerFactory.getLogger(javaClass)

    @GetMapping("/exercise_type")
    fun getAllExerciseType(): ResponseEntity<List<ExerciseType>> {
        val list: List<ExerciseType> = exerciseTypeRepository.findAll()
        logger.info(" -- Get All exercise types..")
        return ResponseEntity.ok().body(list)
    }



    @PostMapping("/exercise_type")
    fun createNewExerciseType(@Valid @RequestBody exerciseType: ExerciseType): ResponseEntity<ExerciseType> {
        logger.info("Create new exercise type: $exerciseType")
        return ResponseEntity.ok().body(exerciseTypeRepository.save(exerciseType))
    }


    @GetMapping("/exercise_type/{id}")
    fun getExerciseTypeById(@PathVariable(value = "id") exerciseTypeId: Long): ResponseEntity<ExerciseType> {
        logger.info("Get exercise type by id: $exerciseTypeId")
        return exerciseTypeRepository.findById(exerciseTypeId).map { exerciseType -> 
            ResponseEntity.ok(exerciseType)
        }.orElse(ResponseEntity.notFound().build())
    }

    @GetMapping("exercise_type/active")
    fun getActiveExerciseType(): ResponseEntity<List<ExerciseType>> {
        val list: List<ExerciseType> = exerciseTypeRepository.getActiveExerciseTypes()
        logger.info("-- Get Active Exercise Types with Images and Translation -- $list")
        return ResponseEntity.ok().body(list)
    }

    @PostMapping("/exercise_type/{id}")
    fun updateExerciseTypesById(@PathVariable(value = "id") exerciseTypeId: Long,
                          @Valid @RequestBody newExerciseType: ExerciseType): ResponseEntity<ExerciseType> {
        logger.info("Update exercise type by id: $exerciseTypeId with object $newExerciseType")
        return exerciseTypeRepository.findById(exerciseTypeId).map { existingExerciseType ->
            val updatedExerciseType: ExerciseType = existingExerciseType
                    .copy(name = newExerciseType.name, 
                        description = newExerciseType.description,
                        treeId = newExerciseType.treeId)
            ResponseEntity.ok().body(exerciseTypeRepository.save(updatedExerciseType))
        }.orElse(ResponseEntity.notFound().build())

    }
}