package com.aitrainer.api.test

import com.aitrainer.api.controller.ExerciseController
import com.aitrainer.api.controller.ExerciseResultController
import com.aitrainer.api.model.ExerciseResult
import com.aitrainer.api.model.Exercises
import com.aitrainer.api.repository.ExerciseResultRepository
import com.aitrainer.api.repository.ExercisesRepository
import org.junit.jupiter.api.Test
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.HttpStatus
import org.springframework.http.ResponseEntity
import kotlin.test.assertEquals
import kotlin.test.assertTrue

@SpringBootTest
class ExerciseResultTest {

    @Autowired
    private lateinit var exerciseResultRepository: ExerciseResultRepository

    @Test
    fun testGet() {
        val controller = ExerciseResultController(exerciseResultRepository)
        val response = controller.getExerciseResultsByCustomerId(90)

        val exerciseResults = response.body
        assertTrue(exerciseResults is List)
        assertEquals(exerciseResults!!.size, 4)
        assertEquals(exerciseResults[0].customerId, 90)
        assertEquals(exerciseResults[0].exerciseId, 1)
        assertEquals(exerciseResults[0].value, 134.0)
        assertEquals(exerciseResults[2].resultType, "development")
    }

    @Test
    fun testInsert() {
        val result = ExerciseResult(
            exerciseId = 3,
            customerId = 103,
            value = 100.0,
            dateFrom = "2020-05-13 04:32:00",
            resultType = "calorie"
        )

        val controller = ExerciseResultController(exerciseResultRepository)

        val response = controller.createNewExerciseResult(result)

        val exerciseNew = response.body

        assertTrue(exerciseNew is ExerciseResult)
        assertTrue(exerciseNew!!.exercisePlanId == null)
        assertEquals(exerciseNew.customerId, 103)
        assertEquals(exerciseNew.resultType, "calorie")

        exerciseResultRepository.delete(exerciseNew)
    }


}